==> cdes-api-6.15.10-20250321.153640-2.jar: at/cdes/api/project/compositeDto/ProjectPageInfo.java <==
/* Copyright (C) 2022 ev-i Informationstechnologie GmbH */

package at.cdes.api.project.compositeDto;

import java.util.HashMap;
import java.util.List;

import at.cdes.api.dto.DocumentNumberPartGroup;
import at.cdes.api.dto.Localisation;
import at.cdes.api.dto.Network;
import at.cdes.api.dto.Person;
import at.cdes.api.dto.Project;
import at.cdes.api.dto.ProjectHoliday;
import at.cdes.api.dto.ReviewCycleResultOption;
import at.cdes.api.dto.RoleType;
import at.cdes.api.joinDto.OrganisationPersonSelectionJoin;

public class ProjectPageInfo {
    
    private List<Network> networks; 
    private Network network;
    private Project project;
    private List<ProjectHoliday> projectHolidays;
    private Person createdBy;
    private List<Person> projectLeaders;
    private List<ObjectPlannerDefinitionInfo> objectPlannerDefinitionInfos;
    private List<RoleType> roleTypes;
    private Boolean hasObjectPlannerDefinition;
    
    private List<DocumentNumberPartGroup> documentNumberPartGroups;
    private List<ReviewCycleResultOption> reviewCycleResultOptions;
    private List<Localisation> localisations;
    private List<OrganisationPersonSelectionJoin> organisationPersonSelectionJoins;
    private List<Project> existingProjects;
    private Boolean hasExistingDocuments;
    private HashMap<Long, Integer> partGroupIdToMaxProjectCodeLength;
    
    public List<Network> getNetworks() {
        return this.networks;
    }
    public void setNetworks(List<Network> networks) {
        this.networks = networks;
    }
    public Network getNetwork() {
        return this.network;
    }
    public void setNetwork(Network network) {
        this.network = network;
    }
    public Project getProject() {
        return this.project;
    }
    public void setProject(Project project) {
        this.project = project;
    }
    public List<ProjectHoliday> getProjectHolidays() {
        return this.projectHolidays;
    }
    public void setProjectHolidays(List<ProjectHoliday> projectHolidays) {
        this.projectHolidays = projectHolidays;
    }
    public Person getCreatedBy() {
        return this.createdBy;
    }
    public void setCreatedBy(Person createdBy) {
        this.createdBy = createdBy;
    }
    public List<Person> getProjectLeaders() {
        return this.projectLeaders;
    }
    public void setProjectLeaders(List<Person> projectLeaders) {
        this.projectLeaders = projectLeaders;
    }
    public List<ObjectPlannerDefinitionInfo> getObjectPlannerDefinitionInfos() {
        return this.objectPlannerDefinitionInfos;
    }
    public void setObjectPlannerDefinitionInfos(List<ObjectPlannerDefinitionInfo> objectPlannerDefinitionInfos) {
        this.objectPlannerDefinitionInfos = objectPlannerDefinitionInfos;
    }
    public List<RoleType> getRoleTypes() {
        return this.roleTypes;
    }
    public void setRoleTypes(List<RoleType> roleTypes) {
        this.roleTypes = roleTypes;
    }
    public Boolean getHasObjectPlannerDefinition() {
        return this.hasObjectPlannerDefinition;
    }
    public void setHasObjectPlannerDefinition(Boolean hasObjectPlannerDefinition) {
        this.hasObjectPlannerDefinition = hasObjectPlannerDefinition;
    }
    public List<DocumentNumberPartGroup> getDocumentNumberPartGroups() {
        return this.documentNumberPartGroups;
    }
    public void setDocumentNumberPartGroups(List<DocumentNumberPartGroup> documentNumberPartGroups) {
        this.documentNumberPartGroups = documentNumberPartGroups;
    }
    public List<ReviewCycleResultOption> getReviewCycleResultOptions() {
        return this.reviewCycleResultOptions;
    }
    public void setReviewCycleResultOptions(List<ReviewCycleResultOption> reviewCycleResultOptions) {
        this.reviewCycleResultOptions = reviewCycleResultOptions;
    }
    public List<Localisation> getLocalisations() {
        return this.localisations;
    }
    public void setLocalisations(List<Localisation> localisations) {
        this.localisations = localisations;
    }
    public List<OrganisationPersonSelectionJoin> getOrganisationPersonSelectionJoins() {
        return this.organisationPersonSelectionJoins;
    }
    public void setOrganisationPersonSelectionJoins(List<OrganisationPersonSelectionJoin> organisationPersonSelectionJoins) {
        this.organisationPersonSelectionJoins = organisationPersonSelectionJoins;
    }
    public List<Project> getExistingProjects() {
        return this.existingProjects;
    }
    public void setExistingProjects(List<Project> existingProjects) {
        this.existingProjects = existingProjects;
    }
    public Boolean getHasExistingDocuments() {
        return this.hasExistingDocuments;
    }
    public void setHasExistingDocuments(Boolean hasExistingDocuments) {
        this.hasExistingDocuments = hasExistingDocuments;
    }
	public HashMap<Long, Integer> getPartGroupIdToMaxProjectCodeLength() {
		return this.partGroupIdToMaxProjectCodeLength;
	}
	public void setPartGroupIdToMaxProjectCodeLength(HashMap<Long, Integer> partGroupIdToMaxProjectCodeLength) {
		this.partGroupIdToMaxProjectCodeLength = partGroupIdToMaxProjectCodeLength;
	}
}

==> cdes-api-6.15.35-20251113.164928-1.jar: at/cdes/api/project/compositeDto/ProjectPageInfo.java <==
/* Copyright (C) 2022 ev-i Informationstechnologie GmbH */

package at.cdes.api.project.compositeDto;

import java.util.HashMap;
import java.util.List;

import at.cdes.api.dto.DocumentNumberPartGroup;
import at.cdes.api.dto.Localisation;
import at.cdes.api.dto.Network;
import at.cdes.api.dto.Person;
import at.cdes.api.dto.Project;
import at.cdes.api.dto.ProjectHoliday;
import at.cdes.api.dto.ReviewCycleResultOption;
import at.cdes.api.dto.RoleType;
import at.cdes.api.joinDto.OrganisationPersonSelectionJoin;

public class ProjectPageInfo {
    
    private List<Network> networks; 
    private Network network;
    private Project project;
    private List<ProjectHoliday> projectHolidays;
    private Person createdBy;
    private List<Person> projectLeaders;
    private List<ObjectPlannerDefinitionInfo> objectPlannerDefinitionInfos;
    private List<RoleType> roleTypes;
    private Boolean hasObjectPlannerDefinition;
    
    private List<DocumentNumberPartGroup> documentNumberPartGroups;
    private List<ReviewCycleResultOption> reviewCycleResultOptions;
    private List<Localisation> localisations;
    private List<OrganisationPersonSelectionJoin> organisationPersonSelectionJoins;
    private List<Project> existingProjects;
    private Boolean hasExistingDocuments;
    private HashMap<Long, Integer> partGroupIdToMaxProjectCodeLength;
    private Boolean isOebbProject;
    
    public List<Network> getNetworks() {
        return this.networks;
    }
    public void setNetworks(List<Network> networks) {
        this.networks = networks;
    }
    public Network getNetwork() {
        return this.network;
    }
    public void setNetwork(Network network) {
        this.network = network;
    }
    public Project getProject() {
        return this.project;
    }
    public void setProject(Project project) {
        this.project = project;
    }
    public List<ProjectHoliday> getProjectHolidays() {
        return this.projectHolidays;
    }
    public void setProjectHolidays(List<ProjectHoliday> projectHolidays) {
        this.projectHolidays = projectHolidays;
    }
    public Person getCreatedBy() {
        return this.createdBy;
    }
    public void setCreatedBy(Person createdBy) {
        this.createdBy = createdBy;
    }
    public List<Person> getProjectLeaders() {
        return this.projectLeaders;
    }
    public void setProjectLeaders(List<Person> projectLeaders) {
        this.projectLeaders = projectLeaders;
    }
    public List<ObjectPlannerDefinitionInfo> getObjectPlannerDefinitionInfos() {
        return this.objectPlannerDefinitionInfos;
    }
    public void setObjectPlannerDefinitionInfos(List<ObjectPlannerDefinitionInfo> objectPlannerDefinitionInfos) {
        this.objectPlannerDefinitionInfos = objectPlannerDefinitionInfos;
    }
    public List<RoleType> getRoleTypes() {
        return this.roleTypes;
    }
    public void setRoleTypes(List<RoleType> roleTypes) {
        this.roleTypes = roleTypes;
    }
    public Boolean getHasObjectPlannerDefinition() {
        return this.hasObjectPlannerDefinition;
    }
    public void setHasObjectPlannerDefinition(Boolean hasObjectPlannerDefinition) {
        this.hasObjectPlannerDefinition = hasObjectPlannerDefinition;
    }
    public List<DocumentNumberPartGroup> getDocumentNumberPartGroups() {
        return this.documentNumberPartGroups;
    }
    public void setDocumentNumberPartGroups(List<DocumentNumberPartGroup> documentNumberPartGroups) {
        this.documentNumberPartGroups = documentNumberPartGroups;
    }
    public List<ReviewCycleResultOption> getReviewCycleResultOptions() {
        return this.reviewCycleResultOptions;
    }
    public void setReviewCycleResultOptions(List<ReviewCycleResultOption> reviewCycleResultOptions) {
        this.reviewCycleResultOptions = reviewCycleResultOptions;
    }
    public List<Localisation> getLocalisations() {
        return this.localisations;
    }
    public void setLocalisations(List<Localisation> localisations) {
        this.localisations = localisations;
    }
    public List<OrganisationPersonSelectionJoin> getOrganisationPersonSelectionJoins() {
        return this.organisationPersonSelectionJoins;
    }
    public void setOrganisationPersonSelectionJoins(List<OrganisationPersonSelectionJoin> organisationPersonSelectionJoins) {
        this.organisationPersonSelectionJoins = organisationPersonSelectionJoins;
    }
    public List<Project> getExistingProjects() {
        return this.existingProjects;
    }
    public void setExistingProjects(List<Project> existingProjects) {
        this.existingProjects = existingProjects;
    }
    public Boolean getHasExistingDocuments() {
        return this.hasExistingDocuments;
    }
    public void setHasExistingDocuments(Boolean hasExistingDocuments) {
        this.hasExistingDocuments = hasExistingDocuments;
    }
	public HashMap<Long, Integer> getPartGroupIdToMaxProjectCodeLength() {
		return this.partGroupIdToMaxProjectCodeLength;
	}
	public void setPartGroupIdToMaxProjectCodeLength(HashMap<Long, Integer> partGroupIdToMaxProjectCodeLength) {
		this.partGroupIdToMaxProjectCodeLength = partGroupIdToMaxProjectCodeLength;
	}
	public Boolean getIsOebbProject() {
		return this.isOebbProject;
	}
	public void setIsOebbProject(Boolean isOebbProject) {
		this.isOebbProject = isOebbProject;
	}
}
